import logging

logger = logging.getLogger(__name__)


class Handler(object):
    def __init__(self, config=None):
        self.config = config

    def filter(self, result, previous_state):
        """ Used to determine whether a result should be reacted to or not.
        Should return True if it should be reacted to, False if not.
        Meant to be overridden by subclasses, or else always returns True.
        """
        return True

    def _process(self, result, previous_state):
        if self.filter(result, previous_state):
            logger.debug("Filter returned true for %s, reacting.", result.id)
            return self.process(result, previous_state)
        logger.debug("Filter returned false for %s, skipping.", result.id)

    def process(self, result, previous_state):
        """ Meant to be overridden by subclasses - should handle the actual
        process of reacting to a result.
        """
        raise NotImplementedError



import os
from setuptools import setup, find_packages
import glob

src_dir = os.path.dirname(__file__)


def read(filename):
    full_path = os.path.join(src_dir, filename)
    with open(full_path) as fd:
        return fd.read()


setup(
    name='nymms',
    version='0.2.4',
    author='Michael Barrett',
    author_email='loki77@gmail.com',
    license="New BSD license",
    url="https://github.com/cloudtools/nymms",
    description='Not Your Mother\'s Monitoring System (NYMMS)',
    long_description=read('README.rst'),
    classifiers=[
        "Topic :: System :: Monitoring",
        "License :: OSI Approved :: BSD License",
        "Development Status :: 3 - Alpha"],
    packages=find_packages(),
    scripts=glob.glob(os.path.join(src_dir, 'scripts', 'nymms_*')),
)
